@@ -36,9 +36,9 @@ void EnvironmentSettingsRulesPageTest::shouldHaveDefaultValue()
 {
     EnvironmentSettingsRulesPage w;
 
-    QLabel *lab = w.findChild<QLabel *>(QStringLiteral("label"));
+    auto *lab = w.findChild<QLabel *>(QStringLiteral("label"));
     QVERIFY(lab);
-    EnvironmentPlainTextEdit *plainText = w.findChild<EnvironmentPlainTextEdit *>(QStringLiteral("richtext"));
+    auto *plainText = w.findChild<EnvironmentPlainTextEdit *>(QStringLiteral("richtext"));
     QVERIFY(plainText);
     QVERIFY(plainText->toPlainText().isEmpty());
     QVERIFY(plainText->isReadOnly());
@@ -47,7 +47,7 @@ void EnvironmentSettingsRulesPageTest::shouldHaveDefaultValue()
 void EnvironmentSettingsRulesPageTest::shouldSetRules()
 {
     EnvironmentSettingsRulesPage w;
-    EnvironmentPlainTextEdit *plainText = w.findChild<EnvironmentPlainTextEdit *>(QStringLiteral("richtext"));
+    auto *plainText = w.findChild<EnvironmentPlainTextEdit *>(QStringLiteral("richtext"));
     QString rules = QStringLiteral("Rules for qt\ntest");
     w.setRules(rules);
     QVERIFY(plainText->toPlainText().endsWith(rules));
