@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -64,7 +64,7 @@ bool CategoryTypeComboBox::loggingCategoryIsNotDefault() const
     return type() != mDefaultCategories;
 }
 
-void CategoryTypeComboBox::setDefaultCategories(const LoggingCategory::LoggingType &defaultCategories)
+void CategoryTypeComboBox::setDefaultCategories(LoggingCategory::LoggingType defaultCategories)
 {
     mDefaultCategories = defaultCategories;
 }
