@@ -26,7 +26,6 @@
 #include "categorywarning.h"
 #include "loadcategoriesjob.h"
 #include "saverulesjob.h"
-#include "kdebugsettingsloadingcategories.h"
 
 #include <KLocalizedString>
 #include <KConfigGroup>
@@ -49,7 +48,7 @@ constexpr char KDebugSettingsDialogGroupName[] = "KDebugSettingsDialog";
 KDebugSettingsDialog::KDebugSettingsDialog(QWidget *parent)
     : QDialog(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
 
     mCategoryWarning = new CategoryWarning(this);
     mCategoryWarning->setObjectName(QStringLiteral("categorywarning"));
