@@ -101,7 +101,7 @@ void LoadCategoriesJob::start()
     const int number(mCategories.count());
     const QList<KDebugSettingsUtil::LoadLoggingCategory> originalQtCategories = KDebugSettingsUtil::readLoggingQtCategories(mFileName);
     QList<KDebugSettingsUtil::LoadLoggingCategory> qtCategories;
-    for (KDebugSettingsUtil::LoadLoggingCategory cat : originalQtCategories) {
+    for (KDebugSettingsUtil::LoadLoggingCategory cat : originalQtCategories) { // clazy:exclude=range-loop
         for (const RenameCategory &catRenamed : qAsConst(mRenameCategories)) {
             if (cat.logName == catRenamed.originalName) {
                 cat.logName = catRenamed.newName;
@@ -164,7 +164,6 @@ void LoadCategoriesJob::start()
                     break;
                 case KDebugSettingsUtil::LoadLoggingCategory::Off:
                     tmp.loggingType = LoggingCategory::Off;
-                    tmp.enabled = false;
                     break;
                 case KDebugSettingsUtil::LoadLoggingCategory::Info:
                     tmp.loggingType = LoggingCategory::Info;
