@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2017-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2017-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -51,10 +51,10 @@ bool SaveRulesJob::start()
     //Save Rules
     QTextStream out(&qtlogging);
     out << QLatin1String("[Rules]\n");
-    for (const LoggingCategory &cat : mListKde) {
+    for (const LoggingCategory &cat : qAsConst(mListKde)) {
         out << cat.createRule() + QLatin1Char('\n');
     }
-    for (const LoggingCategory &cat : mListCustom) {
+    for (const LoggingCategory &cat : qAsConst(mListCustom)) {
         out << cat.createCustomRule() + QLatin1Char('\n');
     }
     return true;
